==> haskell-persistent-2.6.1-1-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-persistent.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: persistent
version: 2.6.1
id: persistent-2.6.1-LORYsaMbvrJ8uG4UdMWDds
key: persistent-2.6.1-LORYsaMbvrJ8uG4UdMWDds
license: MIT
maintainer: Michael Snoyman <michael@snoyman.com>, Greg Weber <greg@gregweber.info>
stability: Stable
homepage: http://www.yesodweb.com/book/persistent
synopsis: Type-safe, multi-backend data serialization.
description:
    Hackage documentation generation is not reliable. For up to date documentation, please see: <http://www.stackage.org/package/persistent>.
category: Database, Yesod
author: Michael Snoyman <michael@snoyman.com>
exposed: True
exposed-modules:
    Database.Persist Database.Persist.Quasi Database.Persist.Types
    Database.Persist.Class Database.Persist.Sql
    Database.Persist.Sql.Util Database.Persist.Sql.Types.Internal
hidden-modules: Database.Persist.Types.Base
                Database.Persist.Class.DeleteCascade
                Database.Persist.Class.PersistEntity
                Database.Persist.Class.PersistQuery
                Database.Persist.Class.PersistUnique
                Database.Persist.Class.PersistConfig
                Database.Persist.Class.PersistField
                Database.Persist.Class.PersistStore Database.Persist.Sql.Migration
                Database.Persist.Sql.Internal Database.Persist.Sql.Types
                Database.Persist.Sql.Raw Database.Persist.Sql.Run
                Database.Persist.Sql.Class Database.Persist.Sql.Orphan.PersistQuery
                Database.Persist.Sql.Orphan.PersistStore
                Database.Persist.Sql.Orphan.PersistUnique
abi: fa51674125cae84aa2d45ebaf3e4ea99
trusted: False
import-dirs: /usr/lib/ghc-8.0.1/site-local/persistent-2.6.1
library-dirs: /usr/lib/ghc-8.0.1/site-local/persistent-2.6.1
data-dir: /usr/share/x86_64-linux-ghc-8.0.1/persistent-2.6.1
hs-libraries: HSpersistent-2.6.1-LORYsaMbvrJ8uG4UdMWDds
depends:
    aeson-1.0.2.1-580HLk2Nlp5BZ0wDg2BMVx
    attoparsec-0.13.1.0-6gEFbI8p8A3LThVdJgpVvH base-4.9.0.0
    base64-bytestring-1.0.0.1-In9M41tLtcS9QYt3QpGpNY
    blaze-html-0.8.1.3-J9yr8vH3H9ALelvCpTjDjF
    blaze-markup-0.7.1.1-JmLydCOPoKfKgaFgoOctdP bytestring-0.10.8.1
    conduit-1.2.9-IqfCpUleYsf85Inkwdla2 containers-0.5.7.1
    exceptions-0.8.3-5cAKIsqc1DD7jaNW3zLxAN
    fast-logger-2.4.10-2uiHrtzLDm9E79SAJUHzbw
    http-api-data-0.3.5-F5OI65ALGA2HMQIdkF75QL
    lifted-base-0.2.3.10-GN8bGJb6NKpLjv5n9gQH0C
    monad-control-1.0.1.0-CVvkY5Vr2NNGCNJRXug3iR
    monad-logger-0.3.20.2-JTAIQ2hISya9krzRihq4vG
    mtl-2.2.1-6qsR1PHUy5lL47Hpoa4jCM
    old-locale-1.0.0.7-6glXNhHF891B41ZfuI8hU8
    path-pieces-0.2.1-EkkcipvGNTB6jNvz5dfdoN
    resource-pool-0.2.3.2-3moP3n1CqLz53yrpIJMjdi
    resourcet-1.1.9-CymaqmR8zCeCrSnerfb4Fa
    scientific-0.3.4.10-HyHkymmV2uwD8dEKuPMVuU
    silently-1.2.5-Ek776fxSdtm4h8aXqt6CNw
    tagged-0.8.5-I7Gu0uzBLkQJCVUvdvwKKq template-haskell-2.11.0.0
    text-1.2.2.1-FgcR4Xf0VlEHD9HLxzq9WJ time-1.6.0.1
    transformers-0.5.2.0 transformers-base-0.4.4-LWS58Nywv1PJoy1IFDbvS4
    unordered-containers-0.2.7.2-2cqAiy5FQsv48ljFn9vXL1
    vector-0.11.0.0-BEDZb5o2QOhGbIm6ky7rl6
haddock-interfaces: /usr/share/doc/haskell-persistent/html/persistent.haddock
haddock-html: /usr/share/doc/haskell-persistent/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-persistent-2.6.1-2-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-persistent.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: persistent
version: 2.6.1
id: persistent-2.6.1-3leueDxHDOBK1fLPg0Tb11
key: persistent-2.6.1-3leueDxHDOBK1fLPg0Tb11
license: MIT
maintainer: Michael Snoyman <michael@snoyman.com>, Greg Weber <greg@gregweber.info>
stability: Stable
homepage: http://www.yesodweb.com/book/persistent
synopsis: Type-safe, multi-backend data serialization.
description:
    Hackage documentation generation is not reliable. For up to date documentation, please see: <http://www.stackage.org/package/persistent>.
category: Database, Yesod
author: Michael Snoyman <michael@snoyman.com>
exposed: True
exposed-modules:
    Database.Persist Database.Persist.Quasi Database.Persist.Types
    Database.Persist.Class Database.Persist.Sql
    Database.Persist.Sql.Util Database.Persist.Sql.Types.Internal
hidden-modules: Database.Persist.Types.Base
                Database.Persist.Class.DeleteCascade
                Database.Persist.Class.PersistEntity
                Database.Persist.Class.PersistQuery
                Database.Persist.Class.PersistUnique
                Database.Persist.Class.PersistConfig
                Database.Persist.Class.PersistField
                Database.Persist.Class.PersistStore Database.Persist.Sql.Migration
                Database.Persist.Sql.Internal Database.Persist.Sql.Types
                Database.Persist.Sql.Raw Database.Persist.Sql.Run
                Database.Persist.Sql.Class Database.Persist.Sql.Orphan.PersistQuery
                Database.Persist.Sql.Orphan.PersistStore
                Database.Persist.Sql.Orphan.PersistUnique
abi: d6566f058b48a1cf73f4513e437c9ae1
trusted: False
import-dirs: /usr/lib/ghc-8.0.1/site-local/persistent-2.6.1
library-dirs: /usr/lib/ghc-8.0.1/site-local/persistent-2.6.1
data-dir: /usr/share/x86_64-linux-ghc-8.0.1/persistent-2.6.1
hs-libraries: HSpersistent-2.6.1-3leueDxHDOBK1fLPg0Tb11
depends:
    aeson-1.0.2.1-L9CPp1k63Y0LjsmlB4O5pz
    attoparsec-0.13.1.0-6gEFbI8p8A3LThVdJgpVvH base-4.9.0.0
    base64-bytestring-1.0.0.1-In9M41tLtcS9QYt3QpGpNY
    blaze-html-0.8.1.3-J9yr8vH3H9ALelvCpTjDjF
    blaze-markup-0.7.1.1-JmLydCOPoKfKgaFgoOctdP bytestring-0.10.8.1
    conduit-1.2.9-IqfCpUleYsf85Inkwdla2 containers-0.5.7.1
    exceptions-0.8.3-5cAKIsqc1DD7jaNW3zLxAN
    fast-logger-2.4.10-2uiHrtzLDm9E79SAJUHzbw
    http-api-data-0.3.5-F5OI65ALGA2HMQIdkF75QL
    lifted-base-0.2.3.10-GN8bGJb6NKpLjv5n9gQH0C
    monad-control-1.0.1.0-CVvkY5Vr2NNGCNJRXug3iR
    monad-logger-0.3.20.2-JTAIQ2hISya9krzRihq4vG
    mtl-2.2.1-6qsR1PHUy5lL47Hpoa4jCM
    old-locale-1.0.0.7-6glXNhHF891B41ZfuI8hU8
    path-pieces-0.2.1-EkkcipvGNTB6jNvz5dfdoN
    resource-pool-0.2.3.2-3moP3n1CqLz53yrpIJMjdi
    resourcet-1.1.9-CymaqmR8zCeCrSnerfb4Fa
    scientific-0.3.4.10-HyHkymmV2uwD8dEKuPMVuU
    silently-1.2.5-Ek776fxSdtm4h8aXqt6CNw
    tagged-0.8.5-I7Gu0uzBLkQJCVUvdvwKKq template-haskell-2.11.0.0
    text-1.2.2.1-FgcR4Xf0VlEHD9HLxzq9WJ time-1.6.0.1
    transformers-0.5.2.0 transformers-base-0.4.4-LWS58Nywv1PJoy1IFDbvS4
    unordered-containers-0.2.7.2-2cqAiy5FQsv48ljFn9vXL1
    vector-0.11.0.0-BEDZb5o2QOhGbIm6ky7rl6
haddock-interfaces: /usr/share/doc/haskell-persistent/html/persistent.haddock
haddock-html: /usr/share/doc/haskell-persistent/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
